@@ -1,4 +1,3 @@
-# flake8: NOQA: W605
 """Helper methods and mixins for libtmux.
 
 libtmux.common
@@ -27,7 +26,7 @@ logger = logging.getLogger(__name__)
 TMUX_MIN_VERSION = "1.8"
 
 #: Most recent version of tmux supported
-TMUX_MAX_VERSION = "3.3"
+TMUX_MAX_VERSION = "3.4"
 
 SessionDict = t.Dict[str, t.Any]
 WindowDict = t.Dict[str, t.Any]
@@ -188,20 +187,21 @@ class EnvironmentMixin:
 
 
 class tmux_cmd:
-    """:term:`tmux(1)` command via :py:mod:`subprocess`.
+    """Run any :term:`tmux(1)` command through :py:mod:`subprocess`.
 
     Examples
     --------
-    .. code-block:: python
+    Create a new session, check for error:
 
-        proc = tmux_cmd('new-session', '-s%' % 'my session')
+    >>> proc = tmux_cmd(f'-L{server.socket_name}', 'new-session', '-d', '-P', '-F#S')
+    >>> if proc.stderr:
+    ...     raise exc.LibTmuxException(
+    ...         'Command: %s returned error: %s' % (proc.cmd, proc.stderr)
+    ...     )
+    ...
 
-        if proc.stderr:
-            raise exc.LibTmuxException(
-                'Command: %s returned error: %s' % (proc.cmd, proc.stderr)
-            )
-
-        print('tmux command returned %s' % proc.stdout)
+    >>> print(f'tmux command returned {" ".join(proc.stdout)}')
+    tmux command returned 2
 
     Equivalent to:
 
@@ -215,7 +215,7 @@ class tmux_cmd:
         Renamed from ``tmux`` to ``tmux_cmd``.
     """
 
-    def __init__(self, *args: t.Any, **kwargs: t.Any) -> None:
+    def __init__(self, *args: t.Any) -> None:
         tmux_bin = shutil.which("tmux")
         if not tmux_bin:
             raise exc.TmuxCommandNotFound()
