@@ -1,4 +1,3 @@
-# flake8: NOQA: W605
 """Pythonization of the :ref:`tmux(1)` pane.
 
 libtmux.pane
@@ -11,7 +10,11 @@ import typing as t
 import warnings
 from typing import overload
 
-from libtmux.common import tmux_cmd
+from libtmux.common import has_gte_version, tmux_cmd
+from libtmux.constants import (
+    RESIZE_ADJUSTMENT_DIRECTION_FLAG_MAP,
+    ResizeAdjustmentDirection,
+)
 from libtmux.neo import Obj, fetch_obj
 
 from . import exc
@@ -27,8 +30,7 @@ logger = logging.getLogger(__name__)
 
 @dataclasses.dataclass()
 class Pane(Obj):
-    """
-    A :term:`tmux(1)` :term:`Pane` [pane_manual]_.
+    """:term:`tmux(1)` :term:`Pane` [pane_manual]_.
 
     ``Pane`` instances can send commands directly to a pane, or traverse
     between linked tmux objects.
@@ -72,7 +74,11 @@ class Pane(Obj):
     def refresh(self) -> None:
         """Refresh pane attributes from tmux."""
         assert isinstance(self.pane_id, str)
-        return super()._refresh(obj_key="pane_id", obj_id=self.pane_id)
+        return super()._refresh(
+            obj_key="pane_id",
+            obj_id=self.pane_id,
+            list_extra_args=("-a",),
+        )
 
     @classmethod
     def from_pane_id(cls, server: "Server", pane_id: str) -> "Pane":
@@ -106,49 +112,129 @@ class Pane(Obj):
     Commands (pane-scoped)
     """
 
-    def cmd(self, cmd: str, *args: t.Any, **kwargs: t.Any) -> tmux_cmd:
-        """Return :meth:`Server.cmd` defaulting to ``target_pane`` as target.
+    def cmd(self, cmd: str, *args: t.Any) -> tmux_cmd:
+        """Execute tmux subcommand within pane context.
 
-        Send command to tmux with :attr:`pane_id` as ``target-pane``.
+        Automatically adds ``-t`` for object's pane ID to the command. Pass ``-t``
+        in args to override.
 
-        Specifying ``('-t', 'custom-target')`` or ``('-tcustom_target')`` in
-        ``args`` will override using the object's ``pane_id`` as target.
+        Examples
+        --------
+        >>> pane.cmd('split-window', '-P').stdout[0]
+        'libtmux...:...'
+
+        From raw output to an enriched `Pane` object:
+
+        >>> Pane.from_pane_id(pane_id=pane.cmd(
+        ... 'split-window', '-P', '-F#{pane_id}').stdout[0], server=pane.server)
+        Pane(%... Window(@... ...:..., Session($1 libtmux_...)))
+
+        Returns
+        -------
+        :meth:`server.cmd`
         """
-        if not any(arg.startswith("-t") for arg in args):
+        if not any("-t" in str(x) for x in args):
             args = ("-t", self.pane_id, *args)
 
-        return self.server.cmd(cmd, *args, **kwargs)
+        return self.server.cmd(cmd, *args)
 
     """
     Commands (tmux-like)
     """
 
-    def resize_pane(self, *args: t.Any, **kwargs: t.Any) -> "Pane":
-        """
-        ``$ tmux resize-pane`` of pane and return ``self``.
+    def resize(
+        self,
+        # Adjustments
+        adjustment_direction: t.Optional[ResizeAdjustmentDirection] = None,
+        adjustment: t.Optional[int] = None,
+        # Manual
+        height: t.Optional[t.Union[str, int]] = None,
+        width: t.Optional[t.Union[str, int]] = None,
+        # Zoom
+        zoom: t.Optional[bool] = None,
+        # Mouse
+        mouse: t.Optional[bool] = None,
+        # Optional flags
+        trim_below: t.Optional[bool] = None,
+    ) -> "Pane":
+        """Resize tmux pane.
 
         Parameters
         ----------
-        target_pane : str
-            ``target_pane``, or ``-U``,``-D``, ``-L``, ``-R``.
+        adjustment_direction : ResizeAdjustmentDirection, optional
+            direction to adjust, ``Up``, ``Down``, ``Left``, ``Right``.
+        adjustment : ResizeAdjustmentDirection, optional
 
-        Other Parameters
-        ----------------
-        height : int
+        height : int, optional
             ``resize-pane -y`` dimensions
-        width : int
+        width : int, optional
             ``resize-pane -x`` dimensions
 
+        zoom : bool
+            expand pane
+
+        mouse : bool
+            resize via mouse
+
+        trim_below : bool
+            trim below cursor
+
         Raises
         ------
-        exc.LibTmuxException
+        :exc:`exc.LibTmuxException`,
+        :exc:`exc.PaneAdjustmentDirectionRequiresAdjustment`,
+        :exc:`exc.RequiresDigitOrPercentage`
+
+        Returns
+        -------
+        :class:`Pane`
+
+        Notes
+        -----
+        Three types of resizing are available:
+
+        1. Adjustments: ``adjustment_direction`` and ``adjustment``.
+        2. Manual resizing: ``height`` and / or ``width``.
+        3. Zoom / Unzoom: ``zoom``.
         """
-        if "height" in kwargs:
-            proc = self.cmd("resize-pane", "-y%s" % int(kwargs["height"]))
-        elif "width" in kwargs:
-            proc = self.cmd("resize-pane", "-x%s" % int(kwargs["width"]))
-        else:
-            proc = self.cmd("resize-pane", args[0])
+        tmux_args: t.Tuple[str, ...] = ()
+
+        ## Adjustments
+        if adjustment_direction:
+            if adjustment is None:
+                raise exc.PaneAdjustmentDirectionRequiresAdjustment()
+            tmux_args += (
+                f"{RESIZE_ADJUSTMENT_DIRECTION_FLAG_MAP[adjustment_direction]}",
+                str(adjustment),
+            )
+        elif height or width:
+            ## Manual resizing
+            if height:
+                if isinstance(height, str):
+                    if height.endswith("%") and not has_gte_version("3.1"):
+                        raise exc.VersionTooLow
+                    if not height.isdigit() and not height.endswith("%"):
+                        raise exc.RequiresDigitOrPercentage
+                tmux_args += (f"-y{height}",)
+
+            if width:
+                if isinstance(width, str):
+                    if width.endswith("%") and not has_gte_version("3.1"):
+                        raise exc.VersionTooLow
+                    if not width.isdigit() and not width.endswith("%"):
+                        raise exc.RequiresDigitOrPercentage
+
+                tmux_args += (f"-x{width}",)
+        elif zoom:
+            ## Zoom / Unzoom
+            tmux_args += ("-Z",)
+        elif mouse:
+            tmux_args += ("-M",)
+
+        if trim_below:
+            tmux_args += ("-T",)
+
+        proc = self.cmd("resize-pane", *tmux_args)
 
         if proc.stderr:
             raise exc.LibTmuxException(proc.stderr)
@@ -161,8 +247,7 @@ class Pane(Obj):
         start: t.Union["t.Literal['-']", t.Optional[int]] = None,
         end: t.Union["t.Literal['-']", t.Optional[int]] = None,
     ) -> t.Union[str, t.List[str]]:
-        """
-        Capture text from pane.
+        """Capture text from pane.
 
         ``$ tmux capture-pane`` to pane.
         ``$ tmux capture-pane -S -10`` to pane.
@@ -248,7 +333,9 @@ class Pane(Obj):
 
     @overload
     def display_message(
-        self, cmd: str, get_text: "t.Literal[True]"
+        self,
+        cmd: str,
+        get_text: "t.Literal[True]",
     ) -> t.Union[str, t.List[str]]:
         ...
 
@@ -257,10 +344,11 @@ class Pane(Obj):
         ...
 
     def display_message(
-        self, cmd: str, get_text: bool = False
+        self,
+        cmd: str,
+        get_text: bool = False,
     ) -> t.Optional[t.Union[str, t.List[str]]]:
-        """
-        ``$ tmux display-message`` to the pane.
+        """Display message to pane.
 
         Displays a message in target-client status line.
 
@@ -278,6 +366,64 @@ class Pane(Obj):
         self.cmd("display-message", cmd)
         return None
 
+    def kill(
+        self,
+        all_except: t.Optional[bool] = None,
+    ) -> None:
+        """Kill :class:`Pane`.
+
+        ``$ tmux kill-pane``.
+
+        Examples
+        --------
+        Kill a pane:
+
+        >>> pane_1 = pane.split_window()
+
+        >>> pane_1 in window.panes
+        True
+
+        >>> pane_1.kill()
+
+        >>> pane_1 not in window.panes
+        True
+
+        Kill all panes except the current one:
+
+        >>> pane.window.resize(height=100, width=100)
+        Window(@1 1...)
+
+        >>> one_pane_to_rule_them_all = pane.split_window()
+
+        >>> other_panes = pane.split_window(
+        ...     ), pane.split_window()
+
+        >>> all([p in window.panes for p in other_panes])
+        True
+
+        >>> one_pane_to_rule_them_all.kill(all_except=True)
+
+        >>> all([p not in window.panes for p in other_panes])
+        True
+
+        >>> one_pane_to_rule_them_all in window.panes
+        True
+        """
+        flags: t.Tuple[str, ...] = ()
+
+        if all_except:
+            flags += ("-a",)
+
+        proc = self.cmd(
+            "kill-pane",
+            *flags,
+        )
+
+        if proc.stderr:
+            raise exc.LibTmuxException(proc.stderr)
+
+        return None
+
     """
     Commands ("climber"-helpers)
 
@@ -285,14 +431,53 @@ class Pane(Obj):
     additional scoped window info.
     """
 
-    def select_pane(self) -> "Pane":
-        """
-        Select pane. Return ``self``.
+    def select(self) -> "Pane":
+        """Select pane.
 
-        To select a window object asynchrously. If a ``pane`` object exists
-        and is no longer longer the current window, ``w.select_pane()``
-        will make ``p`` the current pane.
+        Examples
+        --------
+        >>> pane = window.active_pane
+        >>> new_pane = window.split_window()
+        >>> pane.refresh()
+        >>> active_panes = [p for p in window.panes if p.pane_active == '1']
+
+        >>> pane in active_panes
+        True
+        >>> new_pane in active_panes
+        False
+
+        >>> new_pane.pane_active == '1'
+        False
+
+        >>> new_pane.select()
+        Pane(...)
+
+        >>> new_pane.pane_active == '1'
+        True
         """
+        proc = self.cmd("select-pane")
+
+        if proc.stderr:
+            raise exc.LibTmuxException(proc.stderr)
+
+        self.refresh()
+
+        return self
+
+    def select_pane(self) -> "Pane":
+        """Select pane.
+
+        Notes
+        -----
+        .. deprecated:: 0.30
+
+           Deprecated in favor of :meth:`.select()`.
+        """
+        warnings.warn(
+            "Pane.select_pane() is deprecated in favor of Pane.select()",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         assert isinstance(self.pane_id, str)
         pane = self.window.select_pane(self.pane_id)
         if pane is None:
@@ -302,12 +487,14 @@ class Pane(Obj):
     def split_window(
         self,
         attach: bool = False,
-        vertical: bool = True,
         start_directory: t.Optional[str] = None,
-        percent: t.Optional[int] = None,
+        vertical: bool = True,
+        shell: t.Optional[str] = None,
+        size: t.Optional[t.Union[str, int]] = None,
+        percent: t.Optional[int] = None,  # deprecated
+        environment: t.Optional[t.Dict[str, str]] = None,
     ) -> "Pane":  # New Pane, not self
-        """
-        Split window at pane and return newly created :class:`Pane`.
+        """Split window at pane and return newly created :class:`Pane`.
 
         Parameters
         ----------
@@ -319,13 +506,22 @@ class Pane(Obj):
             specifies the working directory in which the new pane is created.
         percent: int, optional
             percentage to occupy with respect to current pane
+
+        Notes
+        -----
+        .. deprecated:: 0.28.0
+
+           ``percent=25`` deprecated in favor of ``size="25%"``.
         """
         return self.window.split_window(
             target=self.pane_id,
-            start_directory=start_directory,
             attach=attach,
+            start_directory=start_directory,
             vertical=vertical,
+            shell=shell,
+            size=size,
             percent=percent,
+            environment=environment,
         )
 
     """
@@ -333,8 +529,7 @@ class Pane(Obj):
     """
 
     def set_width(self, width: int) -> "Pane":
-        """
-        Set width of pane.
+        """Set pane width.
 
         Parameters
         ----------
@@ -345,8 +540,7 @@ class Pane(Obj):
         return self
 
     def set_height(self, height: int) -> "Pane":
-        """
-        Set height of pane.
+        """Set pane height.
 
         Parameters
         ----------
@@ -357,8 +551,7 @@ class Pane(Obj):
         return self
 
     def enter(self) -> "Pane":
-        """
-        Send carriage return to pane.
+        """Send carriage return to pane.
 
         ``$ tmux send-keys`` send Enter to the pane.
         """
@@ -447,11 +640,13 @@ class Pane(Obj):
 
         .. deprecated:: 0.16
 
-           Deprecated by attribute lookup.e.g. ``pane['window_name']`` is now
+           Deprecated by attribute lookup, e.g. ``pane['window_name']`` is now
            accessed via ``pane.window_name``.
 
         """
-        warnings.warn("Pane.get() is deprecated", stacklevel=2)
+        warnings.warn(
+            "Pane.get() is deprecated", category=DeprecationWarning, stacklevel=2
+        )
         return getattr(self, key, default)
 
     def __getitem__(self, key: str) -> t.Any:
@@ -463,5 +658,45 @@ class Pane(Obj):
            accessed via ``pane.window_name``.
 
         """
-        warnings.warn(f"Item lookups, e.g. pane['{key}'] is deprecated", stacklevel=2)
+        warnings.warn(
+            f"Item lookups, e.g. pane['{key}'] is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         return getattr(self, key)
+
+    def resize_pane(
+        self,
+        # Adjustments
+        adjustment_direction: t.Optional[ResizeAdjustmentDirection] = None,
+        adjustment: t.Optional[int] = None,
+        # Manual
+        height: t.Optional[t.Union[str, int]] = None,
+        width: t.Optional[t.Union[str, int]] = None,
+        # Zoom
+        zoom: t.Optional[bool] = None,
+        # Mouse
+        mouse: t.Optional[bool] = None,
+        # Optional flags
+        trim_below: t.Optional[bool] = None,
+    ) -> "Pane":
+        """Resize pane, deprecated by :meth:`Pane.resize`.
+
+        .. deprecated:: 0.28
+
+           Deprecated by :meth:`Pane.resize`.
+        """
+        warnings.warn(
+            "Deprecated: Use Pane.resize() instead of Pane.resize_pane()",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
+        return self.resize(
+            adjustment_direction=adjustment_direction,
+            adjustment=adjustment,
+            height=height,
+            width=width,
+            zoom=zoom,
+            mouse=mouse,
+            trim_below=trim_below,
+        )
