@@ -1,4 +1,4 @@
-"""Pythonization of the :term:`tmux(1)` server.
+"""Wrapper for :term:`tmux(1)` server.
 
 libtmux.server
 ~~~~~~~~~~~~~~
@@ -38,8 +38,7 @@ logger = logging.getLogger(__name__)
 
 
 class Server(EnvironmentMixin):
-    """
-    The :term:`tmux(1)` :term:`Server` [server_manual]_.
+    """:term:`tmux(1)` :term:`Server` [server_manual]_.
 
     - :attr:`Server.sessions` [:class:`Session`, ...]
 
@@ -69,10 +68,10 @@ class Server(EnvironmentMixin):
     >>> server.sessions[0].windows
     [Window(@1 1:..., Session($1 ...)]
 
-    >>> server.sessions[0].attached_window
+    >>> server.sessions[0].active_window
     Window(@1 1:..., Session($1 ...))
 
-    >>> server.sessions[0].attached_pane
+    >>> server.sessions[0].active_pane
     Pane(%1 Window(@1 1:..., Session($1 ...)))
 
     References
@@ -136,7 +135,7 @@ class Server(EnvironmentMixin):
             self.colors = colors
 
     def is_alive(self) -> bool:
-        """If server alive or not.
+        """Return True if tmux server alive.
 
         >>> tmux = Server(socket_name="no_exist")
         >>> assert not tmux.is_alive()
@@ -174,15 +173,39 @@ class Server(EnvironmentMixin):
     #
     # Command
     #
-    def cmd(self, *args: t.Any, **kwargs: t.Any) -> tmux_cmd:
-        """
-        Execute tmux command and return output.
+    def cmd(self, cmd: str, *args: t.Any) -> tmux_cmd:
+        """Execute tmux command respective of socket name and file, return output.
 
         Examples
         --------
         >>> server.cmd('display-message', 'hi')
         <libtmux.common.tmux_cmd object at ...>
 
+        New session:
+
+        >>> server.cmd('new-session', '-d', '-P', '-F#{session_id}').stdout[0]
+        '$2'
+
+        >>> session.cmd('new-window', '-P').stdout[0]
+        'libtmux...:2.0'
+
+        Output of `tmux -L ... new-window -P -F#{window_id}` to a `Window` object:
+
+        >>> Window.from_window_id(window_id=session.cmd(
+        ... 'new-window', '-P', '-F#{window_id}').stdout[0], server=session.server)
+        Window(@4 3:..., Session($1 libtmux_...))
+
+        Create a pane from a window:
+
+        >>> window.cmd('split-window', '-P', '-F#{pane_id}').stdout[0]
+        '%5'
+
+        Output of `tmux -L ... split-window -P -F#{pane_id}` to a `Pane` object:
+
+        >>> Pane.from_pane_id(pane_id=window.cmd(
+        ... 'split-window', '-P', '-F#{pane_id}').stdout[0], server=window.server)
+        Pane(%... Window(@... ...:..., Session($1 libtmux_...)))
+
         Returns
         -------
         :class:`common.tmux_cmd`
@@ -193,8 +216,7 @@ class Server(EnvironmentMixin):
 
             Renamed from ``.tmux`` to ``.cmd``.
         """
-
-        cmd_args: t.List[t.Union[str, int]] = list(args)
+        cmd_args: t.List[t.Union[str, int]] = [cmd, *args]
         if self.socket_name:
             cmd_args.insert(0, f"-L{self.socket_name}")
         if self.socket_path:
@@ -209,12 +231,11 @@ class Server(EnvironmentMixin):
             else:
                 raise exc.UnknownColorOption()
 
-        return tmux_cmd(*cmd_args, **kwargs)
+        return tmux_cmd(*cmd_args)
 
     @property
     def attached_sessions(self) -> t.List[Session]:
-        """
-        Return active :class:`Session` objects.
+        """Return active :class:`Session`s.
 
         Examples
         --------
@@ -225,26 +246,10 @@ class Server(EnvironmentMixin):
         -------
         list of :class:`Session`
         """
-        try:
-            sessions = self.sessions
-            attached_sessions = []
-
-            for session in sessions:
-                attached = session.session_attached
-                # for now session_active is a unicode
-                if attached != "0":
-                    logger.debug(f"session {session.name} attached")
-                    attached_sessions.append(session)
-                else:
-                    continue
-
-        except Exception:
-            return []
-        return attached_sessions
+        return self.sessions.filter(session_attached="1")
 
     def has_session(self, target_session: str, exact: bool = True) -> bool:
-        """
-        Return True if session exists. ``$ tmux has-session``.
+        """Return True if session exists.
 
         Parameters
         ----------
@@ -275,13 +280,28 @@ class Server(EnvironmentMixin):
 
         return False
 
-    def kill_server(self) -> None:
-        """``$ tmux kill-server``."""
+    def kill(self) -> None:
+        """Kill tmux server.
+
+        >>> svr = Server(socket_name="testing")
+        >>> svr
+        Server(socket_name=testing)
+
+        >>> svr.new_session()
+        Session(...)
+
+        >>> svr.is_alive()
+        True
+
+        >>> svr.kill()
+
+        >>> svr.is_alive()
+        False
+        """
         self.cmd("kill-server")
 
     def kill_session(self, target_session: t.Union[str, int]) -> "Server":
-        """
-        Kill the tmux session with ``$ tmux kill-session``, return ``self``.
+        """Kill tmux session.
 
         Parameters
         ----------
@@ -305,8 +325,7 @@ class Server(EnvironmentMixin):
         return self
 
     def switch_client(self, target_session: str) -> None:
-        """
-        ``$ tmux switch-client``.
+        """Switch tmux client.
 
         Parameters
         ----------
@@ -325,7 +344,7 @@ class Server(EnvironmentMixin):
             raise exc.LibTmuxException(proc.stderr)
 
     def attach_session(self, target_session: t.Optional[str] = None) -> None:
-        """``$ tmux attach-session`` aka alias: ``$ tmux attach``.
+        """Attach tmux session.
 
         Parameters
         ----------
@@ -357,11 +376,11 @@ class Server(EnvironmentMixin):
         window_command: t.Optional[str] = None,
         x: t.Optional[t.Union[int, "DashLiteral"]] = None,
         y: t.Optional[t.Union[int, "DashLiteral"]] = None,
+        environment: t.Optional[t.Dict[str, str]] = None,
         *args: t.Any,
         **kwargs: t.Any,
     ) -> Session:
-        """
-        Return :class:`Session` from  ``$ tmux new-session``.
+        """Create new session, returns new :class:`Session`.
 
         Uses ``-P`` flag to print session info, ``-F`` for return formatting
         returns new Session object.
@@ -401,10 +420,10 @@ class Server(EnvironmentMixin):
             where the closing of the window upon completion is desired.
         x : [int, str], optional
             Force the specified width instead of the tmux default for a
-            dettached session
+            detached session
         y : [int, str], optional
             Force the specified height instead of the tmux default for a
-            dettached session
+            detached session
 
         Returns
         -------
@@ -440,7 +459,7 @@ class Server(EnvironmentMixin):
                     logger.info("session %s exists. killed it." % session_name)
                 else:
                     raise exc.TmuxSessionExists(
-                        "Session named %s exists" % session_name
+                        "Session named %s exists" % session_name,
                     )
 
         logger.debug(f"creating session {session_name}")
@@ -476,6 +495,15 @@ class Server(EnvironmentMixin):
         if window_command:
             tmux_args += (window_command,)
 
+        if environment:
+            if has_gte_version("3.2"):
+                for k, v in environment.items():
+                    tmux_args += (f"-e{k}={v}",)
+            else:
+                logger.warning(
+                    "Environment flag ignored, tmux 3.2 or newer required.",
+                )
+
         proc = self.cmd("new-session", *tmux_args)
 
         if proc.stderr:
@@ -487,19 +515,20 @@ class Server(EnvironmentMixin):
             os.environ["TMUX"] = env
 
         session_formatters = dict(
-            zip(["session_id"], session_stdout.split(formats.FORMAT_SEPARATOR))
+            zip(["session_id"], session_stdout.split(formats.FORMAT_SEPARATOR)),
         )
 
         return Session.from_session_id(
-            server=self, session_id=session_formatters["session_id"]
+            server=self,
+            session_id=session_formatters["session_id"],
         )
 
     #
     # Relations
     #
     @property
-    def sessions(self) -> QueryList[Session]:  # type:ignore
-        """Sessions belonging server.
+    def sessions(self) -> QueryList[Session]:
+        """Sessions contained in server.
 
         Can be accessed via
         :meth:`.sessions.get() <libtmux._internal.query_list.QueryList.get()>` and
@@ -519,8 +548,8 @@ class Server(EnvironmentMixin):
         return QueryList(sessions)
 
     @property
-    def windows(self) -> QueryList[Window]:  # type:ignore
-        """Windows belonging server.
+    def windows(self) -> QueryList[Window]:
+        """Windows contained in server's sessions.
 
         Can be accessed via
         :meth:`.windows.get() <libtmux._internal.query_list.QueryList.get()>` and
@@ -538,8 +567,8 @@ class Server(EnvironmentMixin):
         return QueryList(windows)
 
     @property
-    def panes(self) -> QueryList[Pane]:  # type:ignore
-        """Panes belonging server.
+    def panes(self) -> QueryList[Pane]:
+        """Panes contained in tmux server (across all windows in all sessions).
 
         Can be accessed via
         :meth:`.panes.get() <libtmux._internal.query_list.QueryList.get()>` and
@@ -549,7 +578,7 @@ class Server(EnvironmentMixin):
             Pane(server=self, **obj)
             for obj in fetch_objs(
                 list_cmd="list-panes",
-                list_extra_args=["-s"],
+                list_extra_args=("-a",),
                 server=self,
             )
         ]
@@ -560,13 +589,16 @@ class Server(EnvironmentMixin):
     # Dunder
     #
     def __eq__(self, other: object) -> bool:
-        assert isinstance(other, Server)
-        return (
-            self.socket_name == other.socket_name
-            and self.socket_path == other.socket_path
-        )
+        """Equal operator for :class:`Server` object."""
+        if isinstance(other, Server):
+            return (
+                self.socket_name == other.socket_name
+                and self.socket_path == other.socket_path
+            )
+        return False
 
     def __repr__(self) -> str:
+        """Representation of :class:`Server` object."""
         if self.socket_name is not None:
             return (
                 f"{self.__class__.__name__}"
@@ -579,9 +611,25 @@ class Server(EnvironmentMixin):
     #
     # Legacy: Redundant stuff we want to remove
     #
-    def _list_panes(self) -> t.List[PaneDict]:
+    def kill_server(self) -> None:
+        """Kill tmux server.
+
+        Notes
+        -----
+        .. deprecated:: 0.30
+
+           Deprecated in favor of :meth:`.kill()`.
+
         """
-        Return list of panes in :py:obj:`dict` form.
+        warnings.warn(
+            "Server.kill_server() is deprecated in favor of Server.kill()",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
+        self.cmd("kill-server")
+
+    def _list_panes(self) -> t.List[PaneDict]:
+        """Return list of panes in :py:obj:`dict` form.
 
         Retrieved from ``$ tmux(1) list-panes`` stdout.
 
@@ -589,46 +637,82 @@ class Server(EnvironmentMixin):
         :class:`util.tmux_cmd` which wraps :py:class:`subprocess.Popen`.
 
         .. deprecated:: 0.16
+
+           Deprecated in favor of :attr:`.panes`.
+
         """
-        warnings.warn("Server._list_panes() is deprecated", stacklevel=2)
+        warnings.warn(
+            "Server._list_panes() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         return [p.__dict__ for p in self.panes]
 
     def _update_panes(self) -> "Server":
-        """
-        Update internal pane data and return ``self`` for chainability.
+        """Update internal pane data and return ``self`` for chainability.
+
+        .. deprecated:: 0.16
+
+           Deprecated in favor of :attr:`.panes` and returning ``self``.
 
         Returns
         -------
         :class:`Server`
-
-        .. deprecated:: 0.16
         """
-        warnings.warn("Server._update_panes() is deprecated", stacklevel=2)
+        warnings.warn(
+            "Server._update_panes() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         self._list_panes()
         return self
 
-    def get_by_id(self, id: str) -> t.Optional[Session]:
-        """
+    def get_by_id(self, session_id: str) -> t.Optional[Session]:
+        """Return session by id. Deprecated in favor of :meth:`.sessions.get()`.
+
         .. deprecated:: 0.16
+
+           Deprecated by :meth:`.sessions.get()`.
+
         """
-        warnings.warn("Server.get_by_id() is deprecated", stacklevel=2)
-        return self.sessions.get(session_id=id, default=None)
+        warnings.warn(
+            "Server.get_by_id() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
+        return self.sessions.get(session_id=session_id, default=None)
 
     def where(self, kwargs: t.Dict[str, t.Any]) -> t.List[Session]:
-        """
+        """Filter through sessions, return list of :class:`Session`.
+
         .. deprecated:: 0.16
+
+           Deprecated by :meth:`.session.filter()`.
+
         """
-        warnings.warn("Server.find_where() is deprecated", stacklevel=2)
+        warnings.warn(
+            "Server.find_where() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         try:
             return self.sessions.filter(**kwargs)
         except IndexError:
             return []
 
     def find_where(self, kwargs: t.Dict[str, t.Any]) -> t.Optional[Session]:
-        """
+        """Filter through sessions, return first :class:`Session`.
+
         .. deprecated:: 0.16
+
+           Slated to be removed in favor of :meth:`.sessions.get()`.
+
         """
-        warnings.warn("Server.find_where() is deprecated", stacklevel=2)
+        warnings.warn(
+            "Server.find_where() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         return self.sessions.get(default=None, **kwargs)
 
     def _list_windows(self) -> t.List[WindowDict]:
@@ -640,16 +724,30 @@ class Server(EnvironmentMixin):
         :class:`common.tmux_cmd` which wraps :py:class:`subprocess.Popen`.
 
         .. deprecated:: 0.16
+
+           Slated to be removed in favor of :attr:`.windows`.
+
         """
-        warnings.warn("Server._list_windows() is deprecated", stacklevel=2)
+        warnings.warn(
+            "Server._list_windows() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         return [w.__dict__ for w in self.windows]
 
     def _update_windows(self) -> "Server":
         """Update internal window data and return ``self`` for chainability.
 
         .. deprecated:: 0.16
+
+           Deprecated in favor of :attr:`.windows` and returning ``self``.
+
         """
-        warnings.warn("Server._update_windows() is deprecated", stacklevel=2)
+        warnings.warn(
+            "Server._update_windows() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         self._list_windows()
         return self
 
@@ -658,15 +756,27 @@ class Server(EnvironmentMixin):
         """Property / alias to return :meth:`~._list_sessions`.
 
         .. deprecated:: 0.16
+
+           Slated to be removed in favor of :attr:`.sessions`.
+
         """
-        warnings.warn("Server._sessions is deprecated", stacklevel=2)
+        warnings.warn(
+            "Server._sessions is deprecated", category=DeprecationWarning, stacklevel=2
+        )
         return self._list_sessions()
 
     def _list_sessions(self) -> t.List["SessionDict"]:
-        """
+        """Return list of session object dictionaries.
+
         .. deprecated:: 0.16
+
+           Slated to be removed in favor of :attr:`.sessions`.
         """
-        warnings.warn("Server._list_sessions() is deprecated", stacklevel=2)
+        warnings.warn(
+            "Server._list_sessions() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         return [s.__dict__ for s in self.sessions]
 
     def list_sessions(self) -> t.List[Session]:
@@ -674,18 +784,29 @@ class Server(EnvironmentMixin):
 
         .. deprecated:: 0.16
 
+           Slated to be removed in favor of :attr:`.sessions`.
+
         Returns
         -------
         list of :class:`Session`
         """
-        warnings.warn("Server.list_sessions is deprecated", stacklevel=2)
+        warnings.warn(
+            "Server.list_sessions is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         return self.sessions
 
     @property
-    def children(self) -> QueryList["Session"]:  # type:ignore
-        """Was used by TmuxRelationalObject (but that's longer used in this class)
+    def children(self) -> QueryList["Session"]:
+        """Was used by TmuxRelationalObject (but that's longer used in this class).
 
         .. deprecated:: 0.16
+
+           Slated to be removed in favor of :attr:`.sessions`.
+
         """
-        warnings.warn("Server.children is deprecated", stacklevel=2)
+        warnings.warn(
+            "Server.children is deprecated", category=DeprecationWarning, stacklevel=2
+        )
         return self.sessions
