@@ -52,10 +52,10 @@ class Session(Obj, EnvironmentMixin):
     >>> session.windows
     [Window(@1 ...:..., Session($1 ...)]
 
-    >>> session.attached_window
+    >>> session.active_window
     Window(@1 ...:..., Session($1 ...)
 
-    >>> session.attached_pane
+    >>> session.active_pane
     Pane(%1 Window(@1 ...:..., Session($1 ...)))
 
     References
@@ -139,12 +139,26 @@ class Session(Obj, EnvironmentMixin):
     #
     # Command
     #
-    def cmd(self, *args: t.Any, **kwargs: t.Any) -> tmux_cmd:
-        """Execute tmux subcommand against target session. See :meth:`server.cmd`.
+    def cmd(self, cmd: str, *args: t.Any) -> tmux_cmd:
+        """Execute tmux subcommand within session context.
+
+        Automatically adds ``-t`` for object's session ID to the command. Pass ``-t``
+        in args to override.
+
+        Examples
+        --------
+        >>> session.cmd('new-window', '-P').stdout[0]
+        'libtmux...:....0'
+
+        From raw output to an enriched `Window` object:
+
+        >>> Window.from_window_id(window_id=session.cmd(
+        ... 'new-window', '-P', '-F#{window_id}').stdout[0], server=session.server)
+        Window(@... ...:..., Session($1 libtmux_...))
 
         Returns
         -------
-        :class:`server.cmd`
+        :meth:`server.cmd`
 
         Notes
         -----
@@ -156,15 +170,14 @@ class Session(Obj, EnvironmentMixin):
         if not any("-t" in str(x) for x in args):
             # insert -t immediately after 1st arg, as per tmux format
             new_args: t.Tuple[str, ...] = ()
-            new_args += (args[0],)
             assert isinstance(self.session_id, str)
             new_args += (
                 "-t",
                 self.session_id,
             )
-            new_args += tuple(args[1:])
+            new_args += args
             args = new_args
-        return self.server.cmd(*args, **kwargs)
+        return self.server.cmd(cmd, *args)
 
     """
     Commands (tmux-like)
@@ -348,17 +361,20 @@ class Session(Obj, EnvironmentMixin):
         if proc.stderr:
             raise exc.LibTmuxException(proc.stderr)
 
-        return self.attached_window
+        return self.active_window
 
     #
     # Computed properties
     #
     @property
-    def attached_window(self) -> "Window":
+    def active_pane(self) -> t.Optional["Pane"]:
+        """Return active :class:`Pane` object."""
+        return self.active_window.active_pane
+
+    @property
+    def active_window(self) -> "Window":
         """Return active :class:`Window` object."""
-        active_windows = [
-            window for window in self.windows if window.window_active == "1"
-        ]
+        active_windows = self.windows.filter(window_active="1")
 
         if len(active_windows) == 1:
             return next(iter(active_windows))
@@ -370,22 +386,106 @@ class Session(Obj, EnvironmentMixin):
         if len(self._windows) == 0:
             raise exc.NoWindowsExist()
 
-    def attach_session(self) -> "Session":
-        """Return ``$ tmux attach-session`` aka alias: ``$ tmux attach``."""
-        proc = self.cmd("attach-session", "-t%s" % self.session_id)
+    def attach(
+        self,
+        _exit: t.Optional[bool] = None,
+        _flags: t.Optional[t.List[str]] = None,
+    ) -> "Session":
+        """Return ``$ tmux attach-session`` aka alias: ``$ tmux attach``.
+
+        Examples
+        --------
+        >>> session = server.new_session()
+
+        >>> session not in server.attached_sessions
+        True
+        """
+        flags: t.Tuple[str, ...] = ()
+
+        if _exit is not None and _exit:
+            flags += ("-x",)
+
+        if _flags is not None and isinstance(_flags, list):
+            flags += tuple(f'{",".join(_flags)}')
+
+        proc = self.cmd(
+            "attach-session",
+            *flags,
+        )
 
         if proc.stderr:
             raise exc.LibTmuxException(proc.stderr)
 
+        self.refresh()
+
         return self
 
-    def kill_session(self) -> None:
-        """Destroy session."""
-        proc = self.cmd("kill-session", "-t%s" % self.session_id)
+    def kill(
+        self,
+        all_except: t.Optional[bool] = None,
+        clear: t.Optional[bool] = None,
+    ) -> None:
+        """Kill :class:`Session`, closes linked windows and detach all clients.
+
+        ``$ tmux kill-session``.
+
+        Parameters
+        ----------
+        all_except : bool, optional
+            Kill all sessions in server except this one.
+        clear : bool, optional
+            Clear alerts (bell, activity, or silence) in all windows.
+
+        Examples
+        --------
+        Kill a session:
+
+        >>> session_1 = server.new_session()
+
+        >>> session_1 in server.sessions
+        True
+
+        >>> session_1.kill()
+
+        >>> session_1 not in server.sessions
+        True
+
+        Kill all sessions except the current one:
+
+        >>> one_session_to_rule_them_all = server.new_session()
+
+        >>> other_sessions = server.new_session(
+        ...     ), server.new_session()
+
+        >>> all([w in server.sessions for w in other_sessions])
+        True
+
+        >>> one_session_to_rule_them_all.kill(all_except=True)
+
+        >>> all([w not in server.sessions for w in other_sessions])
+        True
+
+        >>> one_session_to_rule_them_all in server.sessions
+        True
+        """
+        flags: t.Tuple[str, ...] = ()
+
+        if all_except:
+            flags += ("-a",)
+
+        if clear:  # Clear alerts (bell, activity, or silence) in all windows
+            flags += ("-C",)
+
+        proc = self.cmd(
+            "kill-session",
+            *flags,
+        )
 
         if proc.stderr:
             raise exc.LibTmuxException(proc.stderr)
 
+        return None
+
     def switch_client(self) -> "Session":
         """Switch client to session.
 
@@ -436,7 +536,7 @@ class Session(Obj, EnvironmentMixin):
         self,
         window_name: t.Optional[str] = None,
         start_directory: None = None,
-        attach: bool = True,
+        attach: bool = False,
         window_index: str = "",
         window_shell: t.Optional[str] = None,
         environment: t.Optional[t.Dict[str, str]] = None,
@@ -465,6 +565,10 @@ class Session(Obj, EnvironmentMixin):
                 useful for long-running processes where the closing of the
                 window upon completion is desired.
 
+        .. versionchanged:: 0.28.0
+
+           ``attach`` default changed from ``True`` to ``False``.
+
         Returns
         -------
         :class:`Window`
@@ -496,7 +600,7 @@ class Session(Obj, EnvironmentMixin):
                     window_args += (f"-e{k}={v}",)
             else:
                 logger.warning(
-                    "Cannot set up environment as tmux 3.0 or newer is required.",
+                    "Environment flag ignored, requires tmux 3.0 or newer.",
                 )
 
         if window_shell:
@@ -540,14 +644,6 @@ class Session(Obj, EnvironmentMixin):
         if proc.stderr:
             raise exc.LibTmuxException(proc.stderr)
 
-    #
-    # Computed properties
-    #
-    @property
-    def attached_pane(self) -> t.Optional["Pane"]:
-        """Return active :class:`Pane` object."""
-        return self.attached_window.attached_pane
-
     #
     # Dunder
     #
@@ -591,6 +687,81 @@ class Session(Obj, EnvironmentMixin):
     #
     # Legacy: Redundant stuff we want to remove
     #
+    @property
+    def attached_pane(self) -> t.Optional["Pane"]:
+        """Return active :class:`Pane` object.
+
+        Notes
+        -----
+        .. deprecated:: 0.31
+
+           Deprecated in favor of :meth:`.active_pane`.
+        """
+        warnings.warn(
+            "Session.attached_pane() is deprecated in favor of Session.active_pane()",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
+        return self.active_window.active_pane
+
+    @property
+    def attached_window(self) -> "Window":
+        """Return active :class:`Window` object.
+
+        Notes
+        -----
+        .. deprecated:: 0.31
+
+           Deprecated in favor of :meth:`.active_window`.
+        """
+        warnings.warn(
+            "Session.attached_window() is deprecated in favor of "
+            + "Session.active_window()",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
+        return self.active_window
+
+    def attach_session(self) -> "Session":
+        """Return ``$ tmux attach-session`` aka alias: ``$ tmux attach``.
+
+        Notes
+        -----
+        .. deprecated:: 0.30
+
+           Deprecated in favor of :meth:`.attach()`.
+        """
+        warnings.warn(
+            "Session.attach_session() is deprecated in favor of Session.attach()",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
+        proc = self.cmd("attach-session", "-t%s" % self.session_id)
+
+        if proc.stderr:
+            raise exc.LibTmuxException(proc.stderr)
+
+        return self
+
+    def kill_session(self) -> None:
+        """Destroy session.
+
+        Notes
+        -----
+        .. deprecated:: 0.30
+
+           Deprecated in favor of :meth:`.kill()`.
+        """
+        warnings.warn(
+            "Session.kill_session() is deprecated in favor of Session.kill()",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
+        proc = self.cmd("kill-session", "-t%s" % self.session_id)
+
+        if proc.stderr:
+            raise exc.LibTmuxException(proc.stderr)
+
     def get(self, key: str, default: t.Optional[t.Any] = None) -> t.Any:
         """Return key-based lookup. Deprecated by attributes.
 
@@ -600,7 +771,9 @@ class Session(Obj, EnvironmentMixin):
            accessed via ``session.session_name``.
 
         """
-        warnings.warn("Session.get() is deprecated", stacklevel=2)
+        warnings.warn(
+            "Session.get() is deprecated", category=DeprecationWarning, stacklevel=2
+        )
         return getattr(self, key, default)
 
     def __getitem__(self, key: str) -> t.Any:
@@ -614,6 +787,7 @@ class Session(Obj, EnvironmentMixin):
         """
         warnings.warn(
             f"Item lookups, e.g. session['{key}'] is deprecated",
+            category=DeprecationWarning,
             stacklevel=2,
         )
         return getattr(self, key)
@@ -626,7 +800,11 @@ class Session(Obj, EnvironmentMixin):
            Deprecated by :meth:`.windows.get()`.
 
         """
-        warnings.warn("Session.get_by_id() is deprecated", stacklevel=2)
+        warnings.warn(
+            "Session.get_by_id() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         return self.windows.get(window_id=session_id, default=None)
 
     def where(self, kwargs: t.Dict[str, t.Any]) -> t.List[Window]:
@@ -637,7 +815,9 @@ class Session(Obj, EnvironmentMixin):
            Deprecated by :meth:`.windows.filter()`.
 
         """
-        warnings.warn("Session.where() is deprecated", stacklevel=2)
+        warnings.warn(
+            "Session.where() is deprecated", category=DeprecationWarning, stacklevel=2
+        )
         try:
             return self.windows.filter(**kwargs)
         except IndexError:
@@ -651,7 +831,11 @@ class Session(Obj, EnvironmentMixin):
            Slated to be removed in favor of :meth:`.windows.get()`.
 
         """
-        warnings.warn("Session.find_where() is deprecated", stacklevel=2)
+        warnings.warn(
+            "Session.find_where() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         return self.windows.get(default=None, **kwargs)
 
     def _list_windows(self) -> t.List["WindowDict"]:
@@ -662,7 +846,11 @@ class Session(Obj, EnvironmentMixin):
            Slated to be removed in favor of :attr:`.windows`.
 
         """
-        warnings.warn("Session._list_windows() is deprecated", stacklevel=2)
+        warnings.warn(
+            "Session._list_windows() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         return [w.__dict__ for w in self.windows]
 
     @property
@@ -674,7 +862,9 @@ class Session(Obj, EnvironmentMixin):
            Slated to be removed in favor of :attr:`.windows`.
 
         """
-        warnings.warn("Session._windows is deprecated", stacklevel=2)
+        warnings.warn(
+            "Session._windows is deprecated", category=DeprecationWarning, stacklevel=2
+        )
         return self._list_windows()
 
     def list_windows(self) -> t.List["Window"]:
@@ -685,7 +875,11 @@ class Session(Obj, EnvironmentMixin):
            Slated to be removed in favor of :attr:`.windows`.
 
         """
-        warnings.warn("Session.list_windows() is deprecated", stacklevel=2)
+        warnings.warn(
+            "Session.list_windows() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         return self.windows
 
     @property
@@ -697,5 +891,7 @@ class Session(Obj, EnvironmentMixin):
            Slated to be removed in favor of :attr:`.windows`.
 
         """
-        warnings.warn("Session.children is deprecated", stacklevel=2)
+        warnings.warn(
+            "Session.children is deprecated", category=DeprecationWarning, stacklevel=2
+        )
         return self.windows
