@@ -85,7 +85,7 @@ def retry_until(
     Examples
     --------
     >>> def fn():
-    ...     p = session.attached_window.attached_pane
+    ...     p = session.active_window.active_pane
     ...     return p.pane_current_path is not None
 
     >>> retry_until(fn)
@@ -192,8 +192,7 @@ def temp_session(
     If no ``session_name`` is entered, :func:`get_test_session_name` will make
     an unused session name.
 
-    The session will destroy itself upon closing with :meth:`Session.
-    kill_session()`.
+    The session will destroy itself upon closing with :meth:`Session.session()`.
 
     Parameters
     ----------
@@ -228,7 +227,7 @@ def temp_session(
         yield session
     finally:
         if server.has_session(session_name):
-            session.kill_session()
+            session.kill()
     return
 
 
@@ -242,7 +241,7 @@ def temp_window(
     Return a context manager with a temporary window.
 
     The window will destroy itself upon closing with :meth:`window.
-    kill_window()`.
+    kill()`.
 
     If no ``window_name`` is entered, :func:`get_test_window_name` will make
     an unused window name.
@@ -290,7 +289,7 @@ def temp_window(
         yield window
     finally:
         if len(session.windows.filter(window_id=window_id)) > 0:
-            window.kill_window()
+            window.kill()
     return
 
 
