@@ -13,11 +13,15 @@ import warnings
 
 from libtmux._internal.query_list import QueryList
 from libtmux.common import has_gte_version, tmux_cmd
+from libtmux.constants import (
+    RESIZE_ADJUSTMENT_DIRECTION_FLAG_MAP,
+    ResizeAdjustmentDirection,
+)
 from libtmux.neo import Obj, fetch_obj, fetch_objs
 from libtmux.pane import Pane
 
 from . import exc
-from .common import PaneDict, WindowOptionDict, handle_option_error
+from .common import PaneDict, WindowOptionDict, handle_option_error, has_lt_version
 from .formats import FORMAT_SEPARATOR
 
 if t.TYPE_CHECKING:
@@ -29,8 +33,7 @@ logger = logging.getLogger(__name__)
 
 @dataclasses.dataclass()
 class Window(Obj):
-    """
-    A :term:`tmux(1)` :term:`Window` [window_manual]_.
+    """:term:`tmux(1)` :term:`Window` [window_manual]_.
 
     Holds :class:`Pane` objects.
 
@@ -40,7 +43,7 @@ class Window(Obj):
 
     Examples
     --------
-    >>> window = session.new_window('My project')
+    >>> window = session.new_window('My project', attach=True)
 
     >>> window
     Window(@2 2:My project, Session($... ...))
@@ -50,7 +53,7 @@ class Window(Obj):
     >>> window.panes
     [Pane(...)]
 
-    >>> window.attached_pane
+    >>> window.active_pane
     Pane(...)
 
     Relations moving up:
@@ -58,10 +61,10 @@ class Window(Obj):
     >>> window.session
     Session(...)
 
-    >>> window.window_id == session.attached_window.window_id
+    >>> window.window_id == session.active_window.window_id
     True
 
-    >>> window == session.attached_window
+    >>> window == session.active_window
     True
 
     >>> window in session.windows
@@ -86,6 +89,7 @@ class Window(Obj):
             obj_key="window_id",
             obj_id=self.window_id,
             list_cmd="list-windows",
+            list_extra_args=("-a",),
         )
 
     @classmethod
@@ -109,8 +113,8 @@ class Window(Obj):
         return Session.from_session_id(server=self.server, session_id=self.session_id)
 
     @property
-    def panes(self) -> QueryList["Pane"]:  # type: ignore
-        """Panes belonging windows.
+    def panes(self) -> QueryList["Pane"]:
+        """Panes contained by window.
 
         Can be accessed via
         :meth:`.panes.get() <libtmux._internal.query_list.QueryList.get()>` and
@@ -132,34 +136,54 @@ class Window(Obj):
     Commands (pane-scoped)
     """
 
-    def cmd(self, cmd: str, *args: t.Any, **kwargs: t.Any) -> tmux_cmd:
-        """Return :meth:`Server.cmd` defaulting to ``target_window`` as target.
+    def cmd(
+        self,
+        cmd: str,
+        *args: t.Any,
+    ) -> tmux_cmd:
+        """Execute tmux subcommand within window context.
 
-        Send command to tmux with :attr:`window_id` as ``target-window``.
+        Automatically adds ``-t`` for object's indow ID to the command. Pass ``-t``
+        in args to override.
 
-        Specifying ``('-t', 'custom-target')`` or ``('-tcustom_target')`` in
-        ``args`` will override using the object's ``window_id`` as target.
+        Examples
+        --------
+        Create a pane from a window:
+
+        >>> window.cmd('split-window', '-P', '-F#{pane_id}').stdout[0]
+        '%...'
+
+        Magic, directly to a `Pane`:
+
+        >>> Pane.from_pane_id(pane_id=session.cmd(
+        ... 'split-window', '-P', '-F#{pane_id}').stdout[0], server=session.server)
+        Pane(%... Window(@... ...:..., Session($1 libtmux_...)))
+
+        Returns
+        -------
+        :meth:`server.cmd`
         """
-        if not any(arg.startswith("-t") for arg in args):
+        if not any("-t" in str(x) for x in args):
             args = ("-t", self.window_id, *args)
 
-        return self.server.cmd(cmd, *args, **kwargs)
+        return self.server.cmd(cmd, *args)
 
     """
     Commands (tmux-like)
     """
 
     def select_pane(self, target_pane: t.Union[str, int]) -> t.Optional["Pane"]:
-        """
-        Return selected :class:`Pane` through ``$ tmux select-pane``.
+        """Select pane and return selected :class:`Pane`.
+
+        ``$ tmux select-pane``.
 
         Parameters
         ----------
         target_pane : str
             'target_pane', '-U' ,'-D', '-L', '-R', or '-l'.
 
-        Return
-        ------
+        Returns
+        -------
         :class:`Pane`
         """
         if target_pane in ["-l", "-U", "-D", "-L", "-R"]:
@@ -170,20 +194,20 @@ class Window(Obj):
         if proc.stderr:
             raise exc.LibTmuxException(proc.stderr)
 
-        return self.attached_pane
+        return self.active_pane
 
     def split_window(
         self,
         target: t.Optional[t.Union[int, str]] = None,
         start_directory: t.Optional[str] = None,
-        attach: bool = True,
+        attach: bool = False,
         vertical: bool = True,
         shell: t.Optional[str] = None,
-        percent: t.Optional[int] = None,
+        size: t.Optional[t.Union[str, int]] = None,
+        percent: t.Optional[int] = None,  # deprecated
         environment: t.Optional[t.Dict[str, str]] = None,
     ) -> "Pane":
-        """
-        Split window and return the created :class:`Pane`.
+        """Split window and return the created :class:`Pane`.
 
         Used for splitting window and holding in a python object.
 
@@ -205,8 +229,11 @@ class Window(Obj):
             NOTE: When this command exits the pane will close.  This feature
             is useful for long-running processes where the closing of the
             window upon completion is desired.
+        size: int, optional
+            Cell/row or percentage to occupy with respect to current window.
         percent: int, optional
-            percentage to occupy with respect to current window
+            Deprecated in favor of size. Percentage to occupy with respect to current
+            window.
         environment: dict, optional
             Environmental variables for new pane. tmux 3.0+ only. Passthrough to ``-e``.
 
@@ -220,6 +247,14 @@ class Window(Obj):
         By default, this will make the window the pane is created in
         active. To remain on the same window and split the pane in another
         target window, pass in ``attach=False``.
+
+        .. versionchanged:: 0.28.0
+
+           ``attach`` default changed from ``True`` to ``False``.
+
+        .. deprecated:: 0.28.0
+
+           ``percent=25`` deprecated in favor of ``size="25%"``.
         """
         tmux_formats = ["#{pane_id}" + FORMAT_SEPARATOR]
 
@@ -240,8 +275,27 @@ class Window(Obj):
         else:
             tmux_args += ("-h",)
 
+        if size is not None:
+            if has_lt_version("3.1"):
+                if isinstance(size, str) and size.endswith("%"):
+                    tmux_args += (f'-p{str(size).rstrip("%")}',)
+                else:
+                    warnings.warn(
+                        'Ignored size. Use percent in tmux < 3.1, e.g. "size=50%"',
+                        stacklevel=2,
+                    )
+            else:
+                tmux_args += (f"-l{size}",)
+
         if percent is not None:
-            tmux_args += ("-p %d" % percent,)
+            # Deprecated in 3.1 in favor of -l
+            warnings.warn(
+                f'Deprecated in favor of size="{str(percent).rstrip("%")}%" '
+                + ' ("-l" flag) in tmux 3.1+.',
+                category=DeprecationWarning,
+                stacklevel=2,
+            )
+            tmux_args += (f"-p{percent}",)
 
         tmux_args += ("-P", "-F%s" % "".join(tmux_formats))  # output
 
@@ -259,7 +313,7 @@ class Window(Obj):
                     tmux_args += (f"-e{k}={v}",)
             else:
                 logger.warning(
-                    "Cannot set up environment as tmux 3.0 or newer is required."
+                    "Environment flag ignored, tmux 3.0 or newer required.",
                 )
 
         if shell:
@@ -280,6 +334,87 @@ class Window(Obj):
 
         return Pane.from_pane_id(server=self.server, pane_id=pane_formatters["pane_id"])
 
+    def resize(
+        self,
+        # Adjustments
+        adjustment_direction: t.Optional[ResizeAdjustmentDirection] = None,
+        adjustment: t.Optional[int] = None,
+        # Manual
+        height: t.Optional[int] = None,
+        width: t.Optional[int] = None,
+        # Expand / Shrink
+        expand: t.Optional[bool] = None,
+        shrink: t.Optional[bool] = None,
+    ) -> "Window":
+        """Resize tmux window.
+
+        Parameters
+        ----------
+        adjustment_direction : ResizeAdjustmentDirection, optional
+            direction to adjust, ``Up``, ``Down``, ``Left``, ``Right``.
+        adjustment : ResizeAdjustmentDirection, optional
+
+        height : int, optional
+            ``resize-window -y`` dimensions
+        width : int, optional
+            ``resize-window -x`` dimensions
+
+        expand : bool
+            expand window
+        shrink : bool
+            shrink window
+
+        Raises
+        ------
+        :exc:`exc.LibTmuxException`,
+        :exc:`exc.PaneAdjustmentDirectionRequiresAdjustment`
+
+        Returns
+        -------
+        :class:`Window`
+
+        Notes
+        -----
+        Three types of resizing are available:
+
+        1. Adjustments: ``adjustment_direction`` and ``adjustment``.
+        2. Manual resizing: ``height`` and / or ``width``.
+        3. Expand or shrink: ``expand`` or ``shrink``.
+        """
+        if not has_gte_version("2.9"):
+            warnings.warn("resize() requires tmux 2.9 or newer", stacklevel=2)
+            return self
+
+        tmux_args: t.Tuple[str, ...] = ()
+
+        ## Adjustments
+        if adjustment_direction:
+            if adjustment is None:
+                raise exc.WindowAdjustmentDirectionRequiresAdjustment()
+            tmux_args += (
+                f"{RESIZE_ADJUSTMENT_DIRECTION_FLAG_MAP[adjustment_direction]}",
+                str(adjustment),
+            )
+        elif height or width:
+            ## Manual resizing
+            if height:
+                tmux_args += (f"-y{int(height)}",)
+            if width:
+                tmux_args += (f"-x{int(width)}",)
+        elif expand or shrink:
+            if expand:
+                tmux_args += ("-A",)
+            elif shrink:
+                tmux_args += ("-a",)
+
+        proc = self.cmd("resize-window", *tmux_args)
+
+        if proc.stderr:
+            raise exc.LibTmuxException(proc.stderr)
+
+        self.refresh()
+        return self
+
     def last_pane(self) -> t.Optional["Pane"]:
         """Return last pane."""
         return self.select_pane("-l")
@@ -363,11 +498,7 @@ class Window(Obj):
         return self
 
     def show_window_options(self, g: t.Optional[bool] = False) -> "WindowOptionDict":
-        """
-        Return a dict of options for the window.
-
-        For familiarity with tmux, the option ``option`` param forwards to
-        pick a single option, forwarding to :meth:`Window.show_window_option`.
+        """Return dict of options for window.
 
         .. versionchanged:: 0.13.0
 
@@ -394,7 +525,10 @@ class Window(Obj):
 
         window_options: "WindowOptionDict" = {}
         for item in output:
-            key, val = shlex.split(item)
+            try:
+                key, val = shlex.split(item)
+            except ValueError:
+                logger.exception(f"Error extracting option: {item}")
             assert isinstance(key, str)
             assert isinstance(val, str)
 
@@ -404,10 +538,11 @@ class Window(Obj):
         return window_options
 
     def show_window_option(
-        self, option: str, g: bool = False
+        self,
+        option: str,
+        g: bool = False,
     ) -> t.Optional[t.Union[str, int]]:
-        """
-        Return a list of options for the window.
+        """Return option value for the target window.
 
         todo: test and return True/False for on/off string
 
@@ -448,8 +583,7 @@ class Window(Obj):
         return value
 
     def rename_window(self, new_name: str) -> "Window":
-        """
-        Return :class:`Window` object ``$ tmux rename-window <new_name>``.
+        """Rename window.
 
         Parameters
         ----------
@@ -458,7 +592,7 @@ class Window(Obj):
 
         Examples
         --------
-        >>> window = session.attached_window
+        >>> window = session.active_window
 
         >>> window.rename_window('My project')
         Window(@1 1:My project, Session($1 ...))
@@ -482,21 +616,67 @@ class Window(Obj):
 
         return self
 
-    def kill_window(self) -> None:
-        """Kill the current :class:`Window` object. ``$ tmux kill-window``."""
+    def kill(
+        self,
+        all_except: t.Optional[bool] = None,
+    ) -> None:
+        """Kill :class:`Window`.
+
+        ``$ tmux kill-window``.
+
+        Examples
+        --------
+        Kill a window:
+
+        >>> window_1 = session.new_window()
+
+        >>> window_1 in session.windows
+        True
+
+        >>> window_1.kill()
+
+        >>> window_1 not in session.windows
+        True
+
+        Kill all windows except the current one:
+
+        >>> one_window_to_rule_them_all = session.new_window()
+
+        >>> other_windows = session.new_window(
+        ...     ), session.new_window()
+
+        >>> all([w in session.windows for w in other_windows])
+        True
+
+        >>> one_window_to_rule_them_all.kill(all_except=True)
+
+        >>> all([w not in session.windows for w in other_windows])
+        True
+
+        >>> one_window_to_rule_them_all in session.windows
+        True
+        """
+        flags: t.Tuple[str, ...] = ()
+
+        if all_except:
+            flags += ("-a",)
+
         proc = self.cmd(
             "kill-window",
-            f"-t{self.session_id}:{self.window_index}",
+            *flags,
         )
 
         if proc.stderr:
             raise exc.LibTmuxException(proc.stderr)
 
+        return None
+
     def move_window(
-        self, destination: str = "", session: t.Optional[str] = None
+        self,
+        destination: str = "",
+        session: t.Optional[str] = None,
     ) -> "Window":
-        """
-        Move the current :class:`Window` object ``$ tmux move-window``.
+        """Move current :class:`Window` object ``$ tmux move-window``.
 
         Parameters
         ----------
@@ -527,26 +707,47 @@ class Window(Obj):
     #
     # Climbers
     #
-    def select_window(self) -> "Window":
-        """
-        Select window. Return ``self``.
+    def select(self) -> "Window":
+        """Select window.
 
         To select a window object asynchrously. If a ``window`` object exists
-        and is no longer longer the current window, ``w.select_window()``
+        and is no longer the current window, ``w.select_window()``
         will make ``w`` the current window.
+
+        Examples
+        --------
+        >>> window = session.active_window
+        >>> new_window = session.new_window()
+        >>> session.refresh()
+        >>> active_windows = [w for w in session.windows if w.window_active == '1']
+
+        >>> new_window.window_active == '1'
+        False
+
+        >>> new_window.select()
+        Window(...)
+
+        >>> new_window.window_active == '1'
+        True
         """
-        assert isinstance(self.window_index, str)
-        return self.session.select_window(self.window_index)
+        proc = self.cmd("select-window")
+
+        if proc.stderr:
+            raise exc.LibTmuxException(proc.stderr)
+
+        self.refresh()
+
+        return self
 
     #
     # Computed properties
     #
     @property
-    def attached_pane(self) -> t.Optional["Pane"]:
-        """Return the attached :class:`Pane`."""
-        for pane in self.panes:
-            if pane.pane_active == "1":
-                return pane
+    def active_pane(self) -> t.Optional["Pane"]:
+        """Return attached :class:`Pane`."""
+        panes = self.panes.filter(pane_active="1")
+        if len(panes) > 0:
+            return panes[0]
         return None
 
     #
@@ -634,6 +835,65 @@ class Window(Obj):
     #
     # Legacy: Redundant stuff we want to remove
     #
+    @property
+    def attached_pane(self) -> t.Optional["Pane"]:
+        """Return attached :class:`Pane`.
+
+        Notes
+        -----
+        .. deprecated:: 0.31
+
+           Deprecated in favor of :meth:`.active_pane`.
+        """
+        warnings.warn(
+            "Window.attached_pane() is deprecated in favor of Window.active_pane()",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
+        panes = self.panes.filter(pane_active="1")
+        if len(panes) > 0:
+            return panes[0]
+        return None
+
+    def select_window(self) -> "Window":
+        """Select window.
+
+        Notes
+        -----
+        .. deprecated:: 0.30
+
+           Deprecated in favor of :meth:`.select()`.
+        """
+        warnings.warn(
+            "Window.select_window() is deprecated in favor of Window.select()",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
+        assert isinstance(self.window_index, str)
+        return self.session.select_window(self.window_index)
+
+    def kill_window(self) -> None:
+        """Kill the current :class:`Window` object. ``$ tmux kill-window``.
+
+        Notes
+        -----
+        .. deprecated:: 0.30
+
+           Deprecated in favor of :meth:`.kill()`.
+        """
+        warnings.warn(
+            "Window.kill_server() is deprecated in favor of Window.kill()",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
+        proc = self.cmd(
+            "kill-window",
+            f"-t{self.session_id}:{self.window_index}",
+        )
+
+        if proc.stderr:
+            raise exc.LibTmuxException(proc.stderr)
+
     def get(self, key: str, default: t.Optional[t.Any] = None) -> t.Any:
         """Return key-based lookup. Deprecated by attributes.
 
@@ -643,7 +903,9 @@ class Window(Obj):
            accessed via ``window.window_name``.
 
         """
-        warnings.warn("Window.get() is deprecated", stacklevel=2)
+        warnings.warn(
+            "Window.get() is deprecated", category=DeprecationWarning, stacklevel=2
+        )
         return getattr(self, key, default)
 
     def __getitem__(self, key: str) -> t.Any:
@@ -655,10 +917,14 @@ class Window(Obj):
            accessed via ``window.window_name``.
 
         """
-        warnings.warn(f"Item lookups, e.g. window['{key}'] is deprecated", stacklevel=2)
+        warnings.warn(
+            f"Item lookups, e.g. window['{key}'] is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         return getattr(self, key)
 
-    def get_by_id(self, id: str) -> t.Optional[Pane]:
+    def get_by_id(self, pane_id: str) -> t.Optional[Pane]:
         """Return pane by id. Deprecated in favor of :meth:`.panes.get()`.
 
         .. deprecated:: 0.16
@@ -666,8 +932,12 @@ class Window(Obj):
            Deprecated by :meth:`.panes.get()`.
 
         """
-        warnings.warn("Window.get_by_id() is deprecated", stacklevel=2)
-        return self.panes.get(pane_id=id, default=None)
+        warnings.warn(
+            "Window.get_by_id() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
+        return self.panes.get(pane_id=pane_id, default=None)
 
     def where(self, kwargs: t.Dict[str, t.Any]) -> t.List[Pane]:
         """Filter through panes, return list of :class:`Pane`.
@@ -677,7 +947,9 @@ class Window(Obj):
            Deprecated by :meth:`.panes.filter()`.
 
         """
-        warnings.warn("Window.where() is deprecated", stacklevel=2)
+        warnings.warn(
+            "Window.where() is deprecated", category=DeprecationWarning, stacklevel=2
+        )
         try:
             return self.panes.filter(**kwargs)
         except IndexError:
@@ -691,7 +963,11 @@ class Window(Obj):
            Slated to be removed in favor of :meth:`.panes.get()`.
 
         """
-        warnings.warn("Window.find_where() is deprecated", stacklevel=2)
+        warnings.warn(
+            "Window.find_where() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         return self.panes.get(default=None, **kwargs)
 
     def _list_panes(self) -> t.List[PaneDict]:
@@ -702,7 +978,11 @@ class Window(Obj):
            Slated to be removed in favor of :attr:`.panes`.
 
         """
-        warnings.warn("Window._list_panes() is deprecated", stacklevel=2)
+        warnings.warn(
+            "Window._list_panes() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         return [pane.__dict__ for pane in self.panes]
 
     @property
@@ -714,7 +994,7 @@ class Window(Obj):
            Slated to be removed in favor of :attr:`.panes`.
 
         """
-        warnings.warn("_panes is deprecated", stacklevel=2)
+        warnings.warn("_panes is deprecated", category=DeprecationWarning, stacklevel=2)
         return self._list_panes()
 
     def list_panes(self) -> t.List["Pane"]:
@@ -725,11 +1005,13 @@ class Window(Obj):
            Slated to be removed in favor of :attr:`.panes`.
 
         """
-        warnings.warn("list_panes() is deprecated", stacklevel=2)
+        warnings.warn(
+            "list_panes() is deprecated", category=DeprecationWarning, stacklevel=2
+        )
         return self.panes
 
     @property
-    def children(self) -> QueryList["Pane"]:  # type:ignore
+    def children(self) -> QueryList["Pane"]:
         """Was used by TmuxRelationalObject (but that's longer used in this class).
 
         .. deprecated:: 0.16
@@ -737,5 +1019,7 @@ class Window(Obj):
            Slated to be removed in favor of :attr:`.panes`.
 
         """
-        warnings.warn("Server.children is deprecated", stacklevel=2)
+        warnings.warn(
+            "Server.children is deprecated", category=DeprecationWarning, stacklevel=2
+        )
         return self.panes
